import { createTheme } from "@material-ui/core/styles";
import { chartColors } from "./Palette";
import createBreakpoints from "@material-ui/core/styles/createBreakpoints";

const breakpoints = createBreakpoints({});

export const theme = createTheme({
  breakpoints,
  overrides: {
    MuiTooltip: {
      tooltip: {
        fontSize: "0.875rem",
        backgroundColor: "#707070ff"
      }
    },
    MuiListItem: {
      root: {
        "&$selected, &$selected:hover": {
          backgroundColor: "#ccccccff"
        }
      },
      button: {
        "&:hover": {
          backgroundColor: "#ddddddff"
        }
      }
    },
    MuiInputBase: {
      root: {
        fontSize: "0.875rem"
      }
    },
    MuiTypography: {
      body1: {
        fontSize: "0.875rem"
      }
    }
  },
  props: { MuiWithWidth: { initialWidth: "lg" } },
  drawer: {
    widthOpen: 240,
    widthClose: 57
  },
  palette: {
    primary: {
      main: "#0099dc"
    },
    secondary: {
      main: "#0d598e"
    },
    status: {
      ok: "#4caf50",
      fail: "#aa2e25",
      neutral: "#000",
      progress: "#ffc107",
      icons: "#454545"
    },
    graph: chartColors
  },
  typography: {
    fontFamily: [
      "-apple-system",
      "BlinkMacSystemFont",
      '"Segoe UI"',
      "Roboto",
      '"Helvetica Neue"',
      "Arial",
      "Noto Sans",
      "sans-serif",
      '"Apple Color Emoji"',
      '"Segoe UI Emoji"',
      '"Segoe UI Symbol"',
      '"Noto Color Emoji"'
    ].join(","),
    h1: {
      fontFamily: "Titillium Web, sans-serif",
      [breakpoints.down("md")]: {
        fontSize: "0.98rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "1.31rem"
      }
    },
    h2: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "1.3rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "1.7rem"
      },
      fontWeight: 600
    },
    h3: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "1.25rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "1.75rem"
      },
      fontWeight: 600
    },
    h4: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0,98rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "1.09rem"
      },
      fontWeight: 600
    },
    h5: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0.98rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    h6: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0.765rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    overline: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0.656rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "0.875rem"
      },
      fontWeight: 600
    },
    body1: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0.765rem !important",
        fontWeight: 600
      },
      [breakpoints.down("md")]: {
        fontSize: "0.875rem !important"
      }
    },
    button: {
      fontFamily: ["Segoe UI", "Roboto", "Noto Sans"].join(","),
      [breakpoints.down("md")]: {
        fontSize: "0,656rem"
      },
      [breakpoints.up("md")]: {
        fontSize: "0,765rem"
      },
      fontWeight: 500
    }
  },
  cccecustomtable: {
    fontSize: "0.765rem"
  },
  infoBadge: {
    bgColor: "#ececec"
  },
  iocNotDeployed: {
    color: "#b2b2b2"
  },
  csentryIdInvalid: {
    color: "#b2b2b2"
  }
});
